Preprocessing
================================

.. automodule:: hwrt.preprocessing
   :members:

.. figure:: dot-reduction.png
   :alt: Dot reduction
   :height: 256px

   Dot reduction



.. figure:: interrupted-stroke.png
   :alt: Stroke connect
   :height: 256px

   Stroke connect


.. figure:: resampling.png
   :alt: Resampling
   :height: 256px

   Resampling


.. figure:: scale-and-shift.png
   :alt: scale and shift
   :height: 256px

   Scale and shift


.. figure:: smooth-1-1-1.png
   :alt: smoothing (Weights: 1:1:1)
   :height: 256px

   Smoothing


.. figure:: wildpoint-2.png
   :alt: Effect of a wild point on scale and shift
   :height: 256px

   Effect of a wild point on scale and shift